@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $DATE = '2015-03-06'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2015-03-24'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,9 @@ use warnings;
 #use Log::Any '$log';
 
 use Data::Sah::Normalize qw(normalize_schema);
+use Getopt::Long::Negate::EN qw(negations_for_option);
 use Getopt::Long::Util qw(parse_getopt_long_opt_spec);
+use List::Util qw(first);
 use Perinci::Sub::GetArgs::Array qw(get_args_from_array);
 use Perinci::Sub::Util qw(err);
 
@@ -73,19 +75,6 @@ sub _arg2opt {
     $opt;
 }
 
-sub _negations_for_opt {
-    my $word = shift;
-    if      ($word =~ /\Awith-(.+)/   ) { return ("without-$1") }
-    elsif ($word =~ /\Awithout-(.+)/) { return ("with-$1")    }
-    elsif ($word =~ /\Ais-(.+)/     ) { return ("isnt-$1")    }
-    elsif ($word =~ /\Aisnt-(.+)/   ) { return ("is-$1")      }
-    elsif ($word =~ /\Aare-(.+)/    ) { return ("arent-$1")   }
-    elsif ($word =~ /\Aarent-(.+)/  ) { return ("are-$1")     }
-    else {
-        return ("no-$word", "no$word");
-    }
-}
-
 # return one or more triplets of Getopt::Long option spec, its parsed structure,
 # and extra stuffs. we do this to avoid having to call
 # parse_getopt_long_opt_spec().
@@ -103,7 +92,7 @@ sub _opt2ospec {
             return ($opt, {opts=>[$opt]});
         } else {
             my @res;
-            my @negs = _negations_for_opt($opt);
+            my @negs = negations_for_option($opt);
             push @res, $opt, {opts=>[$opt]}, {is_neg=>0, neg_opts=>\@negs};
             for (@negs) {
                 push @res, $_, {opts=>[$_]}, {is_neg=>1, pos_opts=>[$opt]};
@@ -963,14 +952,13 @@ sub get_args_from_argv {
     {
         last unless $strict;
 
-        use experimental 'smartmatch';
         last unless $meta->{args_groups};
         my @specified_args = sort keys %$rargs;
         for my $group_spec (@{ $meta->{args_groups} }) {
             my $group_args = $group_spec->{args};
             next unless @$group_args > 1;
             my $rel = $group_spec->{rel};
-            my @args_in_group = grep {$_ ~~ @$group_args} @specified_args;
+            my @args_in_group = grep {my $arg = $_; first {$_ eq $arg} @$group_args} @specified_args;
             if ($rel eq 'one_of') {
                 next unless @args_in_group;
                 if (@args_in_group > 1) {
@@ -986,7 +974,7 @@ sub get_args_from_argv {
             } elsif ($rel eq 'all') {
                 next unless @args_in_group;
                 if (@args_in_group < @$group_args) {
-                    my @missing = grep {!($_ ~~ @specified_args)} @$group_args;
+                    my @missing = grep {my $arg = $_; !(first {$_ eq $arg} @specified_args)} @$group_args;
                     return [
                         400, join(
                             "",
@@ -1027,7 +1015,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.63 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2015-03-06.
+This document describes version 0.64 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2015-03-24.
 
 =head1 SYNOPSIS
 
